package ch.zhaw.projekt2.turnierverwaltung;

import javafx.scene.layout.Pane;

public abstract class FXController {
    TournamentDecorator tournamentDecorator;
    FactoryDecorator factoryDecorator;
    FileIO fileIO;
    Pane pane;
    IsObserver listener;
    LanguageConfigurator languageConfigurator;

    public FXController() {
        listener = new IsObserver() {
            @Override
            public void update() {
                loadContent();
            }
        };
    }

    public void setup(LanguageConfigurator languageConfigurator) {
        this.languageConfigurator = languageConfigurator;
        shareGUIElementWithLanguageConfigurator();
    }

    public void setup(TournamentDecorator tournamentDecorator, FileIO fileIO, FactoryDecorator factoryDecorator, Pane pane, LanguageConfigurator languageConfigurator) {
        this.tournamentDecorator = tournamentDecorator;
        this.fileIO = fileIO;
        this.factoryDecorator = factoryDecorator;
        this.pane = pane;
        this.languageConfigurator = languageConfigurator;
        shareGUIElementWithLanguageConfigurator();
        addListener();
    }

    public abstract void shareGUIElementWithLanguageConfigurator();

    public abstract void loadContent();

    protected void setTournamentDecorator(TournamentDecorator tournamentDecorator) {
        this.tournamentDecorator = tournamentDecorator;
    }

    public void addListener() {
        tournamentDecorator.addListener(listener);
        factoryDecorator.addListener(listener);
    }

    protected TournamentDecorator getTournamentDecorator() {
        return tournamentDecorator;
    }

    protected void setFactoryDecorator(FactoryDecorator factoryDecorator) {
        this.factoryDecorator = factoryDecorator;
    }

    protected FactoryDecorator getFactoryDecorator() {
        return factoryDecorator;
    }

    protected void setFileIO(FileIO fileIO) {
        this.fileIO = fileIO;
    }

    protected FileIO getFileIO() {
        return fileIO;
    }

    protected void setPane(Pane pane) {
        this.pane = pane;
    }

    protected Pane getPane() {
        return pane;
    }

    protected LanguageConfigurator getLanguageConfigurator() {
        return languageConfigurator;
    }
}
