package ch.zhaw.projekt2.turnierverwaltung.main.placesAddFormular;

import ch.zhaw.projekt2.turnierverwaltung.FXController;
import ch.zhaw.projekt2.turnierverwaltung.Place;
import ch.zhaw.projekt2.turnierverwaltung.Tournament;
import javafx.fxml.FXML;
import javafx.scene.control.Button;
import javafx.scene.control.Label;
import javafx.scene.control.ListView;
import javafx.scene.control.TextField;
import javafx.scene.layout.GridPane;
import javafx.scene.layout.VBox;

import javafx.scene.input.MouseEvent;

import java.util.logging.Logger;

/**
 * Controller of the places form, in charge of its functionality.
 */
public class PlacesFormularController extends FXController {


    @FXML
    private Button closeBtn;

    @FXML
    private Button deleteBtn;

    @FXML
    private Label newPlaceTitle;

    @FXML
    private Label placeListTitle;

    @FXML
    private ListView<Place> placeListView;

    @FXML
    private Label placeNameLabel;

    @FXML
    private TextField placeNameTextField;

    @FXML
    private Button saveBtn;


    private static final Logger logger = Logger.getLogger(PlacesFormularController.class.getCanonicalName());


    @Override
    public void shareGUIElementWithLanguageConfigurator() {
        getLanguageConfigurator().recieveLabel(placeListTitle);
        getLanguageConfigurator().recieveLabel(newPlaceTitle);
        getLanguageConfigurator().recieveLabel(placeNameLabel);
        getLanguageConfigurator().recieveLabel(closeBtn);
        getLanguageConfigurator().recieveLabel(deleteBtn);
        getLanguageConfigurator().recieveLabel(saveBtn);

    }

      /**
     * Selects an item (place) from the List view
     */
    @FXML
    void changedSelection() {
        Place place = placeListView.getSelectionModel().getSelectedItems().get(0);
        logger.finer("Selected new Place from list: " + place);
        placeNameTextField.setText(place.getName());
    }

    /**
     * Saves the name of a new place into the list and clears the form
     */
    @FXML
    void savePlace() {
        getTournamentDecorator().savePlace(placeNameTextField.getText());
        logger.fine("Saved " + placeNameTextField + " to the list of places");
        clearForm();
    }

    /**
     * Method clears the input field
     */
    private void clearForm() {
        logger.finer("Clearing input text field");
        placeNameTextField.clear();
    }

    /**
     * Method deletes the currently selected place from the list.
     */
    @FXML
    void delete() {
        Place place = placeListView.getSelectionModel().getSelectedItems().get(0);
        logger.fine("Deleting " + place + "from place list");
        getTournamentDecorator().deletePlace(place);
    }

    /**
     * Closes the current Place view, going back to previous view
     */
    @FXML
    void close() {
        logger.fine("Closing place form");
        getFactoryDecorator().openScheduleView();
    }

    /**
     * Loads the already saved places and displays them on the places list.
     */
    @Override
    public void loadContent() {
        logger.fine("Getting the Saved tournaments into the Places list");
        Tournament tournament = getTournamentDecorator().getTournament();
        if (tournament != null) {
            placeListView.setItems(tournament.getPlaces());
        } else {
            placeListView.getItems().clear();
        }
    }
}
